@@ -5,11 +5,6 @@ from typing import Any, Dict, List
 __virtualname__ = "cmd"
 
 
-def __virtual__(hub):
-    hub.log.debug("cmd state is a work in progress")
-    return False
-
-
 async def run(
     hub,
     ctx,
@@ -36,7 +31,7 @@ async def run(
         /root
 
     shell
-        run the command with default shell
+        Run the command in the shell
 
     stateful
         The command being executed is expected to return data about executing
@@ -53,11 +48,6 @@ async def run(
         Ignore the timeout of commands, which is useful for running nohup
         processes.
     """
-    ### NOTE: The keyword arguments in **kwargs are passed directly to the
-    ###       ``cmd.run`` function and cannot be removed from the function
-    ###       definition, otherwise the use of unsupported arguments in a
-    ###       ``cmd.run`` state will result in a traceback.
-
     ret = {"name": name, "changes": {}, "result": False, "comment": ""}
     test_name = None
     if isinstance(stateful, list) and "test_name" in stateful[0]:
@@ -73,12 +63,7 @@ async def run(
 
     cmd_kwargs = copy.deepcopy(kwargs)
     cmd_kwargs.update(
-        {
-            "cwd": cwd,
-            "shell": shell if hasattr(hub, "grains") else "sh",
-            "env": env,
-            "umask": umask,
-        }
+        {"cwd": cwd, "shell": shell, "env": env, "umask": umask,}
     )
 
     if ctx["test"] and not test_name:
